@@ -372,6 +372,12 @@ def save_file(filename, content, which='wxg'):
 
     outfile = None
     try:
+        if os.path.isfile(filename):
+            with open(filename, 'r') as infile:
+                win_line_ending = infile.readline().endswith("\r\n")
+        else:
+            win_line_ending = sys.platform.startswith("win")
+
         if need_backup:
             backup_name = filename + config.preferences.backup_suffix
             if os.path.isfile(backup_name):
@@ -386,7 +392,7 @@ def save_file(filename, content, which='wxg'):
 
         outfile = open(filename, 'wb')
         for line in content:
-            if sys.platform.startswith("win"):
+            if win_line_ending:
                 line = line.replace(b"\n", b"\r\n")
             outfile.write(line)
         outfile.close()
