@@ -271,7 +271,7 @@ class EditBase(EventsMixin, np.PropertyOwner):
         if not self.widget: return False
         if not self.widget.IsShown() and not isinstance(self.widget, wx.ScrolledWindow): return False
         if self.widget.IsTopLevel():
-            return self.widget.IsShown()
+            return self.widget.GetTopLevelParent().IsShown()
         parent = self.parent
         if parent: return parent.is_visible()
         return self.widget.GetParent().IsShown()
@@ -580,14 +580,15 @@ class ManagedBase(WindowBase):
         # inside the sizer (proportion, borders, alignment...)
         self._has_layout = not sizer.is_virtual()
 
+        self.sizer = sizer
+
         # attributes to keep the values of the sizer properties
         self.pos        = np.LayoutPosProperty(pos)            # position within the sizer, 1-based
         self.span       = np.LayoutSpanProperty((1,1))         # cell spanning for GridBagSizer
         self.proportion = np.LayoutProportionProperty(0)       # item growth in sizer main direction
         self.border     = np.SpinProperty(0, immediate=True)   # border width
-        self.flag       = np.ManagedFlags(wx.ADJUST_MINSIZE)   # alignment, border; expansion in other dir.
+        self.flag       = np.ManagedFlags(0)                   # alignment, border; expansion in other dir.
 
-        self.sizer = sizer
         sizer.add_item(self, pos)
 
     def check_defaults(self):
@@ -628,6 +629,9 @@ class ManagedBase(WindowBase):
     def properties_changed(self, modified):
         WindowBase.properties_changed(self, modified)
         p = self.properties["flag"]
+        if modified and "flag" in modified and self.parent.is_sizer:
+            p._check_value()
+
         if "flag" in modified and "wxSHAPED" in p.value_set and self.proportion:
             self.properties["proportion"].set(0, notify=False)
         elif "option" in modified and self.proportion and "wxSHAPED" in p.value_set:
@@ -1040,14 +1044,15 @@ class EditStylesMixin(np.PropertyOwner):
                 self.sel_marker = None
             old_widget = self.widget
             old_widget.Hide()
-            si = self.sizer.widget.GetItem(old_widget)
+            inside_sizer = self.sizer and not self.sizer.is_virtual()
+            if inside_sizer: si = self.sizer.widget.GetItem(old_widget)
             self.create_widget()
-            compat.SizerItem_SetWindow(si, self.widget)
+            if inside_sizer: compat.SizerItem_SetWindow(si, self.widget)
             compat.DestroyLater(old_widget)
-            self.sizer.item_properties_modified(self)  # will call toplevel Refresh as well
+            if inside_sizer: self.sizer.item_properties_modified(self)  # will call toplevel Refresh as well
 
             self.finish_widget_creation(re_add=False)
-            self.sizer.layout()
+            if inside_sizer: self.sizer.layout()
             if focused:
                 misc.focused_widget = self
                 if self.sel_marker: self.sel_marker.Show(True)
