@@ -788,9 +788,9 @@ class wxGladeFrame(wx.Frame):
 
         if toplevel.widget and toplevel.widget.IsShownOnScreen() and not focused:
             # just raise it
-            if toplevel.widget.IsIconized():
-                toplevel.widget.Iconize(False)
-            toplevel.widget.Raise()
+            if toplevel.widget.GetTopLevelParent().IsIconized():
+                toplevel.widget.GetTopLevelParent().Iconize(False)
+            toplevel.widget.GetTopLevelParent().Raise()
             return
         # open or close
         common.app_tree.show_toplevel(None, widget=toplevel)
@@ -904,7 +904,7 @@ class wxGladeFrame(wx.Frame):
         error_msg = None
         infile = None
 
-        start = time.clock()
+        start = time.time()
 
         common.app_tree.clear()
         common.app_tree.app.init()
@@ -985,7 +985,7 @@ class wxGladeFrame(wx.Frame):
             common.app_tree.app.template_data = template.Template(filename)
             common.app_tree.app.filename = None
 
-        end = time.clock()
+        end = time.time()
         self._logger.info(_('Loading time: %.5f'), end - start)
 
         common.app_tree.app.saved = True
@@ -1331,7 +1331,7 @@ class wxGlade(wx.App):
         common.init_preferences()
 
         self.locale = wx.Locale(wx.LANGUAGE_DEFAULT)  # avoid PyAssertionErrors
-        compat.wx_ArtProviderPush(wxGladeArtProvider())
+        #compat.wx_ArtProviderPush(wxGladeArtProvider())  causes crashes on Cent OS 7
 
         frame = wxGladeFrame()
         self.SetTopWindow(frame)
