@@ -37,7 +37,7 @@ class EditButton(ManagedBase, EditStylesMixin, BitmapMixin):
         # initialise instance properties
         self.label     = np.TextProperty(label, default_value="", multiline="grow")
         self.default   = np.CheckBoxProperty(False, default_value=False)
-        self.stockitem = np.ComboBoxPropertyD(self.STOCKITEMS[0], choices=self.STOCKITEMS)
+        self.stockitem = np.ListBoxPropertyD(self.STOCKITEMS[0], choices=self.STOCKITEMS)
 
         self.bitmap          = np.BitmapPropertyD(min_version=(3,0))
         self.disabled_bitmap = np.BitmapPropertyD(min_version=(3,0))
