@@ -129,6 +129,15 @@ class XmlParser(ContentHandler):
             overwrite = config.default_overwrite
         res['overwrite'] = bool(overwrite)
 
+        try:
+            mark_blocks = int(attrs['mark_blocks'])
+        except (KeyError, ValueError):
+            mark_blocks = True # config.mark_blocks
+        if not overwrite and not mark_blocks:
+            mark_blocks = True
+        res['mark_blocks'] = bool(mark_blocks)
+
+
         res['path'] = attrs.get('path')
 
         res['header_extension'] = attrs.get('header_extension', config.default_header_extension)
@@ -167,7 +176,9 @@ class XmlParser(ContentHandler):
 class XmlWidgetBuilder(XmlParser):
     "Parser used to build the tree of widgets from a given XML file"
 
-    def __init__(self):
+    def __init__(self, filename=None, input_file_version=None):
+        self.filename = filename
+        self.input_file_version = input_file_version
         XmlParser.__init__(self)
 
     def startElement(self, name, attrs):
@@ -188,13 +199,14 @@ class XmlWidgetBuilder(XmlParser):
             p["use_gettext"].set( attrs['use_gettext'] )
             p["is_template"].set( attrs['is_template'] )
             p["overwrite"].set( attrs['overwrite'] )
+            p["mark_blocks"].set( attrs['mark_blocks'] )
             p["indent_mode"].set( attrs['indent_symbol'] )
             p["indent_amount"].set( attrs['indent_amount'] )
             p["for_version"].set( attrs['for_version'] )
 
             modified = ["encoding", "output_path", "class", "name", "multiple_files", "language", "top_window",
-                        "use_gettext", "use_gettext", "is_template", "overwrite", "indent_mode", "indent_amount",
-                        "for_version"]
+                        "use_gettext", "is_template", "overwrite", "mark_blocks",
+                        "indent_mode", "indent_amount", "for_version"]
 
             source_extension = attrs['source_extension']
             if source_extension and source_extension[0] == '.':
@@ -208,6 +220,8 @@ class XmlWidgetBuilder(XmlParser):
 
             app.properties_changed(modified)
             self._delayed_app_properties = {"for_version":attrs['for_version']}
+            if attrs['top_window']:
+                self._delayed_app_properties['top_window'] = attrs['top_window']
             return
 
         if not self._appl_started:
@@ -249,6 +263,7 @@ class XmlWidgetBuilder(XmlParser):
                 return
             if obj.sizeritem:
                 obj.obj.copy_properties( obj.sizeritem, ("option","flag","border","span") )
+                obj.obj.properties["flag"]._check_value()
             obj.obj.on_load()
         else:
             # end of a property or error
@@ -337,6 +352,9 @@ class ProgressXmlWidgetBuilder(XmlWidgetBuilder):
                 self.progress = None
 
 
+class _own_dict(dict):
+    pass  # just be able to add attributes
+
 
 class ClipboardXmlWidgetBuilder(XmlWidgetBuilder):
     """Parser used to cut&paste widgets.
@@ -461,7 +479,7 @@ class ClipboardXmlWidgetBuilder(XmlWidgetBuilder):
                 newname = oldname
             else:
                 newname = self._get_new_name(oldname)
-            attrs = dict(attrs)
+            attrs = _own_dict(attrs)
             attrs['name'] = newname
             if newname!=oldname:
                 attrs['original_name'] = oldname  # for finding position in a virtual sizer
@@ -479,22 +497,6 @@ class ClipboardXmlWidgetBuilder(XmlWidgetBuilder):
             self.depth_level += 1
 
     def endElement(self, name):
-        if name == 'object':
-            obj = self.top()
-            self.depth_level -= 1
-            if not self.depth_level:
-                common.app_tree.auto_expand = True
-                import misc
-                try:
-                    # show the first object and update its layout
-                    #if self.top_obj.node.parent.widget.is_visible():
-                    #    common.app_tree.show_widget(self.top_obj.node)
-                    if self.top_obj.node.parent.widget.widget:
-                        self.top_obj.create_widgets()
-                except AttributeError:
-                    self._logger.exception( _('Exception caused by obj: %s'), self.top_obj )
-                misc.set_focused_widget(self.top_obj)
-
         if name == 'label':
             # if e.g. a button_1 is copied to button_2, also change the label if it was "button_1"
             obj = self.top()
@@ -506,6 +508,22 @@ class ClipboardXmlWidgetBuilder(XmlWidgetBuilder):
 
         XmlWidgetBuilder.endElement(self, name)
 
+        if name!="object": return
+        self.depth_level -= 1
+
+        if not self.depth_level:
+            common.app_tree.auto_expand = True
+            import misc
+            try:
+                # show the first object and update its layout
+                #if self.top_obj.node.parent.widget.is_visible():
+                #    common.app_tree.show_widget(self.top_obj.node)
+                if self.top_obj.node.parent.widget.widget:
+                    self.top_obj.create_widgets()
+            except AttributeError:
+                self._logger.exception( _('Exception caused by obj: %s'), self.top_obj )
+            misc.set_focused_widget(self.top_obj)
+
 
 class XmlWidgetObject(object):
     "A class to encapsulate widget attributes read from a XML file, to store them until the widget can be created"
@@ -514,6 +532,8 @@ class XmlWidgetObject(object):
         # initialise instance logger
         self._logger = logging.getLogger(self.__class__.__name__)
 
+        attrs.input_file_version = parser.input_file_version  # for handling backwards compatibility on loading
+
         self.prop_handlers = Stack()  # a stack of custom handler functions to set properties of this object
         self.parser = parser
         self.in_sizers = False   # if True, the widget is     a sizer, opposite of 'in_windows'
@@ -565,7 +585,9 @@ class XmlWidgetObject(object):
             if builder is None: raise XmlParsingError("Widget '%s' not supported."%base)
             self.obj = builder(attrs, parent, sizer, sizeritem, pos)
             p = self.obj.properties.get("class")
-            if p: p.set(self.klass)
+            if p:
+                p.set(self.klass)
+                common.app_tree.refresh(self.obj.node)
 
             if isinstance(self.obj, edit_sizers.SizerBase):
                 self.in_sizers = True
@@ -578,7 +600,7 @@ class XmlWidgetObject(object):
 
         elif self.klass == 'sizerslot':
             assert sizer is not None, _("malformed wxg file: slots can only be inside sizers!")
-            sizer._add_slot()
+            sizer._add_slot(loading=True)
             sizer.layout()
 
         # push the object on the _objects stack
@@ -594,7 +616,7 @@ class XmlWidgetObject(object):
             prop = self.obj.properties[name]
         except KeyError:
             # unknown property for this object; issue a warning and ignore the property
-            #if config.debugging: raise
+            if config.debugging: raise
             self._logger.error( _("WARNING: Property '%s' not supported by this object ('%s') "), name, self.obj )
             return
         prop.load(val, activate=True)
@@ -630,5 +652,5 @@ class Sizeritem(np.PropertyOwner):
         self.proportion = np.LayoutProportionProperty(0)
         self.span = np.LayoutSpanProperty((1,1))
         self.border = np.SpinProperty(0)
-        self.flag = np.ManagedFlags(None)
+        self.flag = np.ManagedFlags(None, name="sizeritem_flags")
         self.pos = np.SpinProperty(None)
